@@ -1,6 +1,7 @@
 import logging
 import subprocess
 import importlib
+import importlib.machinery
 from urllib.parse import urlparse
 
 import psycopg2
@@ -44,15 +45,18 @@ class ModelRepository:
             conn = self.conpool.getconn()
             cur = conn.cursor()
             if conn:
-                cur.execute("SELECT model from %s where model_name = '%s'", (ModelRepository.MODEL_REPO_TABLE, model_name))
+                cur.execute(f"SELECT model from io_fintix.custom_model where model_name = '{model_name}'")
                 blob = cur.fetchone()
-                output_dir = LOCAL_TRAINING_MODEL_REPO if phase in [TRAINING_PHASE,
-                                                                    EVALUATION_PHASE] else LOCAL_DEPLOY_MODEL_REPO
+                output_dir = os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name)
                 output_file = os.path.join(output_dir, model_name + ".py")
+                if not os.path.exists(output_dir):
+                    os.makedirs(output_dir)
                 with open(output_file, "wb") as modelzip:
                     modelzip.write(blob[0])
                 conn.commit()
+            logging.info(f"model {model_name} have bean downloaded into {output_dir}")
         except Exception as e:
+            logging.error(f"failed to download model {model_name}", e)
             return (
                 NoResult,
                 FintixError(exception=e, message=f"could not download model {model_name} from model repository",
@@ -77,8 +81,10 @@ class ModelRepository:
             model_name = model_name if not model_name.endswith(".ipynb") else model_name.replace(".ipynb", "")
             model_notebook_path = os.path.join(current_dir, model_name + ".ipynb")
             res = subprocess.getoutput(f"jupyter nbconvert --to script {model_notebook_path}")
+            logging.info(f"Successfully convert model '{model_name}' notebook into python executable script")
             return res, NoError
         except Exception as e:
+            logging.error(f"Failed to convert notebook of model {model_name}", e)
             return (
                 NoResult,
                 FintixError(exception=e, message="failed to convert notebook into executable python script",
@@ -102,6 +108,7 @@ class ModelRepository:
             if python_script_content is None:
                 raise Exception("failed to read converted python executable")
         except Exception as e:
+            logging.error(f"Failed to read converted python script of model '{model_name}' notebook", e)
             return (
                 NoResult,
                 FintixError(exception=e, message="failed to zip converted python executable",
@@ -113,10 +120,13 @@ class ModelRepository:
         try:
             conn = self.conpool.getconn()
             cur = conn.cursor()
-            cur.execute("INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES(%s, %s, %s)",
-                        (model_name, model_name, psycopg2.Binary(python_script_content)))
+            script_content = psycopg2.Binary(python_script_content)
+            cur.execute("INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES(%s, %s, %s) ON CONFLICT (model_uid) DO UPDATE SET model = %s WHERE model_uid = '%s'",
+                        (model_name, model_name, script_content, script_content, model_name))
             conn.commit()
+            logging.info(f"Successfully upload converted python script of model '{model_name}' notebook into database")
         except Exception as e:
+            logging.error(f"Failed to upload converted python script of model '{model_name}' notebook into database", e)
             return (
                 NoResult,
                 FintixError(exception=e, message="failed to upload converted python to database", exit_code=None,
@@ -144,11 +154,13 @@ class ModelRepository:
         _, err = self.__download_model(model_name, phase)
         if err:
             return NoResult, err
-        model_dir = LOCAL_TRAINING_MODEL_REPO if phase in [TRAINING_PHASE,
-                                                           EVALUATION_PHASE] else LOCAL_DEPLOY_MODEL_REPO
+        model_dir = os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name)
         try:
-            model = importlib.import_module(model_name, model_dir)
+            loader = importlib.machinery.SourceFileLoader(model_name, os.path.join(model_dir, model_name + ".py"))
+            model = loader.load_module(model_name)
+            logging.info(f"Successfully load model '{model_name}' module from {model_dir}")
         except Exception as e:
+            logging.error(f"Failed to load model '{model_name}' module form {model_dir}", e)
             return (
                 NoResult,
                 FintixError(
